@@ -2,7 +2,7 @@
 library(knitr)
 options(stringsAsFactors=FALSE)
 opts_chunk$set(concordance = TRUE, comment = "", warning = FALSE, message = TRUE, echo = TRUE, results = 'tex', size="footnotesize")
-tmp <- tempdir()
+tmp <- tempdir(check = T)
 suppressPackageStartupMessages(library(vegdata))
 options(tv_home = tmp)
 dir.create(file.path(tmp, 'Species'))
@@ -11,12 +11,13 @@ dir.create(file.path(tmp, 'Data'))
 file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Popup'), to = tmp, recursive = TRUE)
 file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Species'), to = tmp, recursive = TRUE)
 file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Data'), to = tmp, recursive = TRUE)
+# dim(tax('all'))
 
 ## ----load, results='hide'-----------------------------------------------------
 library(vegdata)
 
-## ----eval=TRUE----------------------------------------------------------------
-tv_home <- tv.home()
+## ----eval=FALSE---------------------------------------------------------------
+#  tv_home <- tv.home()
 
 ## ----eval=FALSE---------------------------------------------------------------
 #  options(tv_home="path_to_your_Turboveg_root_directory")
@@ -31,7 +32,7 @@ tv.refl()
 #  tv.refl('your_preferred_list')
 
 ## ----tax, eval =TRUE----------------------------------------------------------
-tax('Brachythecium rutabulum')
+tax('Quercus robur')
 
 ## ----syn----------------------------------------------------------------------
 tax('Elytrigia repens')$TaxonName
@@ -39,7 +40,8 @@ syn('Elytrigia repens')
 
 ## ----childs, eval=FALSE-------------------------------------------------------
 #  child(27, quiet=TRUE)$TaxonName
-#  parent('ACHIMIL')
+#  parent(32)
+#  parent(32, rank = 'FAM')
 
 ## ----db-----------------------------------------------------------------------
 db <- 'taxatest'
@@ -53,7 +55,7 @@ obs <- tv.obs(db)
 # Adding species names
 species <- tax('all', refl=tv.refl(db=db))
 obs$TaxonName <-  species$TaxonName[match(obs$TaxonUsageID, species$TaxonUsageID)]
-head(obs[,c('RELEVE_NR','TaxonUsageID','COVER_CODE','LAYER','TaxonName')])
+head(obs[,c('PlotObservationID','TaxonUsageID','COVER_CODE','LAYER','TaxonName')])
 
 ## ----data---------------------------------------------------------------------
 library(vegdata)
@@ -61,17 +63,17 @@ obs <- tv.obs('taxatest')
 sort(tax(unique(obs$TaxonUsageID))$TaxonName)
 
 ## ----adapt--------------------------------------------------------------------
-obs.tax <- taxval(obs, db='taxatest', ag='adapt', rank='SPE', check.critical = FALSE)
+obs.tax <- taxval(obs, db='taxatest', ag='adapt', rank='SPE', check.critical = FALSE, taxlevels = taxlevels)
 sort(tax(unique(obs.tax$TaxonUsageID), db=db)$TaxonName)
 
 ## ----conflict-----------------------------------------------------------------
 obs.tax <- taxval(obs, db='taxatest', ag='conflict', check.critical = FALSE)
 sort(tax(unique(obs.tax$TaxonUsageID), db=db)$TaxonName)
 
-## ----maxtax-------------------------------------------------------------------
-obs.tax <- taxval(obs, db='taxatest', ag='conflict', maxtaxlevel = 'AGG', check.critical = FALSE, interactive = TRUE)
-obs.tax <- taxval(obs.tax, db='taxatest', ag='adapt', rank='SPE', check.critical = FALSE)
-sort(tax(unique(obs.tax$TaxonUsageID), db=db)$TaxonName)
+## ----maxtax, eval=FALSE-------------------------------------------------------
+#  obs.tax <- taxval(obs, db='taxatest', ag='conflict', maxtaxlevel = 'AGG', check.critical = FALSE, interactive = TRUE)
+#  obs.tax <- taxval(obs.tax, db='taxatest', ag='adapt', rank='SPE', check.critical = FALSE)
+#  sort(tax(unique(obs.tax$TaxonUsageID), db=db)$TaxonName)
 
 ## ----coverperc, echo=2:4, eval=TRUE-------------------------------------------------------------------------
 options(width=120)
@@ -103,7 +105,7 @@ obs.tax$TaxonUsageID[obs.tax$TaxonUsageID == 27] <- 31
 
 ## ----replace------------------------------------------------------------------------------------------------
 taxon.repl <- data.frame(old=c(27), new=c(31))
-obs.tax$TaxonUsageID <- replace(obs.tax$TaxonUsageID, 
+obs.tax$TaxonUsageID <- replace(obs.tax$TaxonUsageID,
                                 match(taxon.repl$old, obs.tax$TaxonUsageID), taxon.repl$new)
 
 ## ----comb.spec, eval=FALSE----------------------------------------------------------------------------------
@@ -126,25 +128,18 @@ levels(clust) <- c('dry.ld','dry.hd', 'wet.hd','wet.ld')
 
 ## ----syntab.mupa--------------------------------------------------------------------------------------------
 require(indicspecies)
-mu <- multipatt(elbaue, clust)
-veg <- elbaue; dec=0
-st <- syntab(elbaue, clust, 'rel', mupa=mu)
-# Print Ellenberg indicator values for soil moisture and nutrient demand
-traits <- tv.traits()
-trait <- traits[traits$LETTERCODE %in% names(elbaue), ]
-rownames(trait) <- trait$LETTERCODE
-trait <- trait[,c('OEK_F', 'OEK_N')]
-print(st, limit=30, trait=trait)
+synt <- syntab(elbaue, clust, mupa=TRUE)
+synt
 
 ## ----nmds, quiet=TRUE, results='hide'-----------------------------------------------------------------------
 ## Data analyses
 library(vegan)
-veg.nmds <- metaMDS(elbaue, distance = "bray", trymax = 5, autotransform =FALSE, 
+veg.nmds <- metaMDS(elbaue, distance = "bray", trymax = 5, autotransform =FALSE,
                     noshare = 1, expand = TRUE, trace = 2)
 #eco <- tv.traits()
 #eco$OEK_F <- as.numeric(eco$OEK_F)
-F <- isc(elbaue, trait.db = 'ecodbase.dbf', ivname = 'OEK_F', method = 'mean')
-N <- isc(elbaue, trait.db = 'ecodbase.dbf', ivname = 'OEK_N', method = 'mean')
+F <- cwm(veg = elbaue, trait.db = 'ecodbase.dbf', ivname = 'OEK_F', method = 'mean')
+N <- cwm(veg = elbaue, trait.db = 'ecodbase.dbf', ivname = 'OEK_N', method = 'mean')
 env <- envfit(veg.nmds, env = data.frame(F, N))
 
 ## ----nmdsplotfun, quiet=TRUE, results='hide'----------------------------------------------------------------
@@ -153,7 +148,7 @@ library(akima)
 color = function(x)rev(topo.colors(x))
 nmds.plot <- function(ordi, site, var1, var2, disp, plottitle =  'NMDS', env = NULL, ...) {
 lplot <- nrow(ordi$points);  lspc <- nrow(ordi$species)
-filled.contour(interp(ordi$points[, 1], ordi$points[, 2], site[, var1]), 
+filled.contour(interp(ordi$points[, 1], ordi$points[, 2], site[, var1], duplicate = 'strip'),
            ylim = c(-1, 1.1), xlim = c(-1.4, 1.4),
            color.palette = color, xlab = var1, ylab = var2, main = plottitle,
            key.title = title(main = var1, cex.main = 0.8, line = 1, xpd = NA),
